@@ -1,11 +1,11 @@
-use Text::PDF::API::Color;
+use Color::Object;
 use Text::PDF::API;
 
         $f=5;
         $pdf=Text::PDF::API->new(pagesize=>'a4', 'compression'=>1);
         $pdf->newFont('Helvetica-Bold');
         $pdf->useFont('Helvetica-Bold',$f);
-	$ff=Text::PDF::API::Color->new();
+	$ff=Color::Object->new();
 	@colors=sort keys %col;
 	foreach $h(0,60,120,180,240,300) {
         	$pdf->newpage();
