@@ -1,130 +1,28 @@
 package Text::PDF::API::UniMap;
 
+$VERSION = "0.1";
 
-use vars qw ($VERSION @EXPORT @EXPORT_OK @EXPORT_TAGS @ISA);
-
-BEGIN {
-    @ISA         = qw(Exporter);
-    @EXPORT      = qw ();
-    @EXPORT_OK   = qw ( utf8_to_ucs2 utf16_to_ucs2 );
-    @EXPORT_TAGS = qw ();
-    $VERSION     = "0.2.1";
-}
-
-sub utf8c_to_ucs4c {
-	my $string=shift @_;
-	my ($c,$out,$len);
-	$c=vec($string,0,8);
-	if($c & 0x80) {
-		if(($c & 0xc0)==0xc0) {
-			if(($c & 0xe0)==0xe0){
-				if(($c & 0xf0)==0xf0) {
-					if(($c & 0xf8)==0xf8) {
-						if(($c & 0xfc)==0xfc) {
-							if(($c & 0xfe)==0xfe) {
-								# not valid !
-								$len=0;
-								$c=0;
-							} else {
-								# 6-byte utf8
-								$len=6;
-								$c = ($c & 0x01) << 30;
-								$c|= (vec($string,1,8) & 0x3f) << 24;
-								$c|= (vec($string,2,8) & 0x3f) << 18;
-								$c|= (vec($string,3,8) & 0x3f) << 12;
-								$c|= (vec($string,4,8) & 0x3f) << 6;
-								$c|= (vec($string,5,8) & 0x3f);
-							}
-						} else {
-							# 5-byte utf8
-							$len=5;
-							$c = ($c & 0x03) << 24;
-							$c|= (vec($string,1,8) & 0x3f) << 18;
-							$c|= (vec($string,2,8) & 0x3f) << 12;
-							$c|= (vec($string,3,8) & 0x3f) << 6;
-							$c|= (vec($string,4,8) & 0x3f);
-						}
-					} else {
-						# 4-byte utf8
-						$len=4;
-						$c = ($c & 0x7) << 18;
-						$c|= (vec($string,1,8) & 0x3f) << 12;
-						$c|= (vec($string,2,8) & 0x3f) << 6;
-						$c|= (vec($string,3,8) & 0x3f);
-					}
-				} else {
-					# 3-byte utf8
-					$len=3;
-					$c=($c & 0x0f) << 12;
-					$c|=((vec($string,1,8) & 0x3f) << 6);
-					$c|=(vec($string,2,8) & 0x3f);
-				}
-			} else {
-				# 2-byte utf8
-				$len=2;
-				$c&=0x1f;
-				$c=$c<<6;
-				$c|=(vec($string,1,8) & 0x3f);
-			}		
-		} else {
-			# not valid
-			$c=0;
-			$len=0;
-		}
-	} else {
-		## ASCII-7bits
-		$len=1;
-	}
-	$out=pack('N',($c & 0xffffffff));
-	return($out,$len);
-}
-
-sub utf8c_to_ucs2c {
-	my ($string)=@_;
-	my ($c,$len)=utf8c_to_ucs4c($string);
-	$c=pack('n',(unpack('N',$c) & 0xffff));
-	$c='' if($len>4);
-	return($c,$len);
-}
-
-sub utf8_to_ucs2 {
-	my $string=shift @_;
-	my($ucs,$len,$final);
-	do {
-		($ucs,$len)=utf8c_to_ucs2c($string);
-		$final.=$ucs;
-		$string=substr($string,$len-length($string),length($string)-$len);
-	} while( ($len>0) && (length($string)>0) );
-	return($final);
-}
-
-sub utf16_to_ucs2 {
-	my $final=shift @_;
-	return($final);
-}
 
 sub new {
 	my $class=shift(@_);
-	my $encoding=lc(shift @_) || 'latin1';
+	my $encoding=lc(shift @_);
 	my $this={};
 	$encoding=~s/[^a-z0-9\-]+//cgi;
 	bless($this,$class);
 	my $buf;
-	my $unimap='';
-	map {
-		if(-e "$_/Text/PDF/API/UniMap/$encoding.map"){
-			$unimap="$_/Text/PDF/API/UniMap/$encoding.map";
+	my $unimapdir; map {
+		if(-d "$_/Text/PDF/API/UniMap"){
+			$unimapdir="$_/Text/PDF/API/UniMap";
 		}
 	} @INC;
-
-	if(! -e $unimap) {
-		die " encoding='$encoding' not supported.";
+	if(! -e "$unimapdir/$encoding.map") {
+		die " $encoding not supported.";
 	} else {
 		$this->{'enc'} = $encoding;
 		$this->{'u2c'} = {};
 		$this->{'c2u'} = {};
 		$this->{'c2n'} = {};
-		open(INF,"$unimap");
+		open(INF,"$unimapdir/$encoding.map");
 		binmode(INF);
 		read(INF,$buf,4);
 		while(!eof(INF)) {
@@ -132,7 +30,7 @@ sub new {
 			my ($ch,$um)=unpack('nn',$buf);
 			$this->{'u2c'}->{$um}=$ch;
 			$this->{'c2u'}->{$ch}=$um;
-			$this->{'c2n'}->{$ch}=$u2n{$um} || sprintf('uni%04X',$um);
+			$this->{'c2n'}->{$ch}=$u2n{$um} || '.notdef';
 		}
 		close(INF);
 		if(wantarray) {
@@ -172,16 +70,12 @@ sub glyphs {
 }
 
 sub unimaps {
-	return( 
-		map {	
-			$_=~s/^.*\/([^\/]+)\.map$/$1/cgi; 
-			lc($_); 
-		} (
-			map { 
-				glob("$_/Text/PDF/API/UniMap/*.map"); 
-			} @INC
-		) 
-	);
+	my $unimapdir; map {
+		if(-d "$_/Text/PDF/API/UniMap"){
+			$unimapdir="$_/Text/PDF/API/UniMap";
+		}
+	} @INC;
+	return( map { $_=~s/^$unimapdir\/(.*)\.map$/$1/cgi; lc($_); } glob("$unimapdir/*.map") );
 }
 
 sub isMap {
